@@ -1,7 +1,7 @@
 """Find translations examples by grepping in .po files.
 """
 
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 import argparse
 import glob
@@ -10,6 +10,7 @@ import sys
 from textwrap import fill
 from typing import Sequence, NamedTuple, List, Tuple, Optional
 from shutil import get_terminal_size
+from subprocess import run, CalledProcessError
 
 import regex
 import polib
@@ -136,14 +137,12 @@ def find_in_po(
 
 def display_results(
     matches: Sequence[Match],
-    pattern: str,
-    line_number: bool,
-    files_with_matches: bool,
+    args: argparse.Namespace,
     grep_colors: GrepColors,
 ):
     """Display matches as a colorfull table."""
     files = {match.file for match in matches}
-    if files_with_matches:  # Just print filenames
+    if args.files_with_matches:  # Just print filenames
         for file in files:
             if grep_colors:
                 print(grep_colors.start("fn") + file + grep_colors.NO_COLOR)
@@ -155,9 +154,9 @@ def display_results(
     term_width = get_terminal_size()[0]
     for match in matches:
         left = match.msgid
-        if line_number:
+        if args.line_number:
             pnum = str(match.line) + ":"
-            if len(files) > 1:
+            if args.print_filenames:
                 pfile = match.file + ":"
             else:
                 pfile = ""
@@ -172,7 +171,10 @@ def display_results(
     if grep_colors:
         print(
             colorize(
-                tabulate(table, tablefmt="fancy_grid"), pattern, grep_colors, prefixes
+                tabulate(table, tablefmt="fancy_grid"),
+                args.pattern,
+                grep_colors,
+                prefixes,
             )
         )
     else:
@@ -273,6 +275,7 @@ def parse_args() -> argparse.Namespace:
     )
     parser.add_argument(
         "--exclude-dir",
+        action="append",
         help="Skip any command-line directory with a name suffix that matches "
         "the pattern.  "
         "When searching recursively, skip any subdirectory whose base name "
@@ -291,18 +294,57 @@ def parse_args() -> argparse.Namespace:
         "environment variable GREP_COLORS. The deprecated environment variable "
         "GREP_COLOR is still supported, but its setting does not have priority.",
     )
+    parser.add_argument(
+        "--blame",
+        action="store_true",
+        help="Annotate each line from git information for the entries of each "
+        "match line. Implies --no-source and --translation.",
+    )
     parser.add_argument("pattern")
     parser.add_argument("path", nargs="*")
-    return parser.parse_args()
+
+    args = parser.parse_args()
+    if args.color == "auto":
+        args.color = sys.stdout.isatty()
+    else:
+        args.color = args.color != "never"
+    if args.fixed_strings:
+        args.pattern = regex.escape(args.pattern)
+    if args.word_regexp:
+        args.pattern = r"\b" + args.pattern + r"\b"
+    if args.ignore_case:
+        args.pattern = r"(?i)" + args.pattern
+    if args.blame:
+        args.no_source = True
+        args.translation = True
+
+    return args
+
+
+def run_git(
+    lines_list: Sequence[int], filename: str, pattern: str, grep_colors: GrepColors
+):
+    """run git blame for the specified lines in filename
+
+    if grep_colors is not None then the pattern is highlighted
+    """
+    cmd_line = ["git", "blame"]
+    cmd_line.extend(f"-L {line},/^$/" for line in lines_list)
+    cmd_line.append(filename)
+    try:
+        result = run(cmd_line, capture_output=True, text=True, check=True)
+    except CalledProcessError as exc:
+        print(exc.stderr, file=sys.stderr)
+        return
+    if grep_colors:
+        print(colorize(result.stdout, pattern, grep_colors))
+    else:
+        print(result.stdout)
 
 
 def main():
     """Command line entry point."""
     args = parse_args()
-    if args.color == "auto":
-        args.color = sys.stdout.isatty()
-    else:
-        args.color = args.color != "never"
     if args.color:
         grep_colors = GrepColors()
         try:
@@ -311,24 +353,34 @@ def main():
             pass
     else:
         grep_colors = None
-    if args.fixed_strings:
-        args.pattern = regex.escape(args.pattern)
-    if args.word_regexp:
-        args.pattern = r"\b" + args.pattern + r"\b"
-    if args.ignore_case:
-        args.pattern = r"(?i)" + args.pattern
     files = process_path(args.path, args.recursive)
+    args.print_filenames = len(files) > 1
     if args.exclude_dir:
-        files = [f for f in files if args.exclude_dir.rstrip(os.sep) + os.sep not in f]
+        files = [
+            f
+            for f in files
+            if not any(excl.rstrip(os.sep) + os.sep in f for excl in args.exclude_dir)
+        ]
     errors, results = find_in_po(args.pattern, files, args.no_source, args.translation)
     if not args.no_messages:
         for error in errors:
             print(error, file=sys.stderr)
+    if args.blame:
+        current_file = ""
+        lines_list = []
+        for res in results:
+            if res.file != current_file:
+                if current_file:
+                    run_git(lines_list, current_file, args.pattern, grep_colors)
+                current_file = res.file
+                lines_list = []
+            lines_list.append(res.line)
+        if lines_list:
+            run_git(lines_list, current_file, args.pattern, grep_colors)
+        return
     display_results(
         results,
-        args.pattern,
-        args.line_number,
-        args.files_with_matches,
+        args,
         grep_colors,
     )
 
